==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/SqlVulnerabilityAssessmentsSetting.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [SqlVulnerabilityAssessmentsSetting].
 */
@PulumiTagMarker
public class SqlVulnerabilityAssessmentsSettingResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: SqlVulnerabilityAssessmentsSettingArgs = SqlVulnerabilityAssessmentsSettingArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend SqlVulnerabilityAssessmentsSettingArgsBuilder.() -> Unit) {
        val builder = SqlVulnerabilityAssessmentsSettingArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): SqlVulnerabilityAssessmentsSetting {
        val builtJavaResource =
            com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return SqlVulnerabilityAssessmentsSetting(builtJavaResource)
    }
}

/**
 * A SQL Vulnerability Assessment.
 * Azure REST API version: 2022-11-01-preview.
 * Other available API versions: 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Create a SQL Vulnerability Assessment policy
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sqlVulnerabilityAssessmentsSetting = new AzureNative.Sql.SqlVulnerabilityAssessmentsSetting("sqlVulnerabilityAssessmentsSetting", new()
 *     {
 *         ResourceGroupName = "vulnerabilityaseessmenttest-4799",
 *         ServerName = "vulnerabilityaseessmenttest-6440",
 *         State = AzureNative.Sql.SqlVulnerabilityAssessmentState.Enabled,
 *         VulnerabilityAssessmentName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewSqlVulnerabilityAssessmentsSetting(ctx, "sqlVulnerabilityAssessmentsSetting", &sql.SqlVulnerabilityAssessmentsSettingArgs{
 * 			ResourceGroupName:           pulumi.String("vulnerabilityaseessmenttest-4799"),
 * 			ServerName:                  pulumi.String("vulnerabilityaseessmenttest-6440"),
 * 			State:                       sql.SqlVulnerabilityAssessmentStateEnabled,
 * 			VulnerabilityAssessmentName: pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSettingArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sqlVulnerabilityAssessmentsSetting = new SqlVulnerabilityAssessmentsSetting("sqlVulnerabilityAssessmentsSetting", SqlVulnerabilityAssessmentsSettingArgs.builder()
 *             .resourceGroupName("vulnerabilityaseessmenttest-4799")
 *             .serverName("vulnerabilityaseessmenttest-6440")
 *             .state("Enabled")
 *             .vulnerabilityAssessmentName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:SqlVulnerabilityAssessmentsSetting default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/sqlVulnerabilityAssessments/{vulnerabilityAssessmentName}
 * ```
 */
public class SqlVulnerabilityAssessmentsSetting internal constructor(
    override val javaResource: com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting,
) : KotlinCustomResource(javaResource, SqlVulnerabilityAssessmentsSettingMapper) {
    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Specifies the state of the SQL Vulnerability Assessment, whether it is enabled or disabled or a state has not been applied yet on the specific database or server.
     */
    public val state: Output<String>?
        get() = javaResource.state().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * SystemData of SqlVulnerabilityAssessmentResource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object SqlVulnerabilityAssessmentsSettingMapper :
    ResourceMapper<SqlVulnerabilityAssessmentsSetting> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting::class == javaResource::class

    override fun map(javaResource: Resource): SqlVulnerabilityAssessmentsSetting =
        SqlVulnerabilityAssessmentsSetting(
            javaResource as
                com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting,
        )
}

/**
 * @see [SqlVulnerabilityAssessmentsSetting].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [SqlVulnerabilityAssessmentsSetting].
 */
public suspend fun sqlVulnerabilityAssessmentsSetting(
    name: String,
    block: suspend SqlVulnerabilityAssessmentsSettingResourceBuilder.() -> Unit,
):
    SqlVulnerabilityAssessmentsSetting {
    val builder = SqlVulnerabilityAssessmentsSettingResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [SqlVulnerabilityAssessmentsSetting].
 * @param name The _unique_ name of the resulting resource.
 */
public fun sqlVulnerabilityAssessmentsSetting(name: String): SqlVulnerabilityAssessmentsSetting {
    val builder = SqlVulnerabilityAssessmentsSettingResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/SqlVulnerabilityAssessmentsSetting.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.sql.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [SqlVulnerabilityAssessmentsSetting].
 */
@PulumiTagMarker
public class SqlVulnerabilityAssessmentsSettingResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: SqlVulnerabilityAssessmentsSettingArgs = SqlVulnerabilityAssessmentsSettingArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend SqlVulnerabilityAssessmentsSettingArgsBuilder.() -> Unit) {
        val builder = SqlVulnerabilityAssessmentsSettingArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): SqlVulnerabilityAssessmentsSetting {
        val builtJavaResource =
            com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return SqlVulnerabilityAssessmentsSetting(builtJavaResource)
    }
}

/**
 * A SQL Vulnerability Assessment.
 * Azure REST API version: 2022-11-01-preview.
 * Other available API versions: 2023-02-01-preview, 2023-05-01-preview, 2023-08-01-preview.
 * ## Example Usage
 * ### Create a SQL Vulnerability Assessment policy
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sqlVulnerabilityAssessmentsSetting = new AzureNative.Sql.SqlVulnerabilityAssessmentsSetting("sqlVulnerabilityAssessmentsSetting", new()
 *     {
 *         ResourceGroupName = "vulnerabilityaseessmenttest-4799",
 *         ServerName = "vulnerabilityaseessmenttest-6440",
 *         State = AzureNative.Sql.SqlVulnerabilityAssessmentState.Enabled,
 *         VulnerabilityAssessmentName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewSqlVulnerabilityAssessmentsSetting(ctx, "sqlVulnerabilityAssessmentsSetting", &sql.SqlVulnerabilityAssessmentsSettingArgs{
 * 			ResourceGroupName:           pulumi.String("vulnerabilityaseessmenttest-4799"),
 * 			ServerName:                  pulumi.String("vulnerabilityaseessmenttest-6440"),
 * 			State:                       sql.SqlVulnerabilityAssessmentStateEnabled,
 * 			VulnerabilityAssessmentName: pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting;
 * import com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSettingArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sqlVulnerabilityAssessmentsSetting = new SqlVulnerabilityAssessmentsSetting("sqlVulnerabilityAssessmentsSetting", SqlVulnerabilityAssessmentsSettingArgs.builder()
 *             .resourceGroupName("vulnerabilityaseessmenttest-4799")
 *             .serverName("vulnerabilityaseessmenttest-6440")
 *             .state("Enabled")
 *             .vulnerabilityAssessmentName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:SqlVulnerabilityAssessmentsSetting default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/sqlVulnerabilityAssessments/{vulnerabilityAssessmentName}
 * ```
 */
public class SqlVulnerabilityAssessmentsSetting internal constructor(
    override val javaResource: com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting,
) : KotlinCustomResource(javaResource, SqlVulnerabilityAssessmentsSettingMapper) {
    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Specifies the state of the SQL Vulnerability Assessment, whether it is enabled or disabled or a state has not been applied yet on the specific database or server.
     */
    public val state: Output<String>?
        get() = javaResource.state().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * SystemData of SqlVulnerabilityAssessmentResource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object SqlVulnerabilityAssessmentsSettingMapper :
    ResourceMapper<SqlVulnerabilityAssessmentsSetting> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting::class == javaResource::class

    override fun map(javaResource: Resource): SqlVulnerabilityAssessmentsSetting =
        SqlVulnerabilityAssessmentsSetting(
            javaResource as
                com.pulumi.azurenative.sql.SqlVulnerabilityAssessmentsSetting,
        )
}

/**
 * @see [SqlVulnerabilityAssessmentsSetting].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [SqlVulnerabilityAssessmentsSetting].
 */
public suspend fun sqlVulnerabilityAssessmentsSetting(
    name: String,
    block: suspend SqlVulnerabilityAssessmentsSettingResourceBuilder.() -> Unit,
):
    SqlVulnerabilityAssessmentsSetting {
    val builder = SqlVulnerabilityAssessmentsSettingResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [SqlVulnerabilityAssessmentsSetting].
 * @param name The _unique_ name of the resulting resource.
 */
public fun sqlVulnerabilityAssessmentsSetting(name: String): SqlVulnerabilityAssessmentsSetting {
    val builder = SqlVulnerabilityAssessmentsSettingResourceBuilder()
    builder.name(name)
    return builder.build()
}
